#!/usr/bin/env ts-node

import { Knex, knex } from "knex";
import { validateSchema } from "../utils/dbValidator";

const config = {
  client: "pg", // or "mysql", "sqlite3"
  connection: {
    host: process.env.DB_HOST || "localhost",
    user: process.env.DB_USER || "root",
    password: process.env.DB_PASS || "",
    database: process.env.DB_NAME || "permissions"
  }
};

async function run() {
  const db = knex(config);
  try {
    await validateSchema(db);
    process.exit(0);
  } catch (err: any) {
    console.error("❌ Validation failed:", err.message);
    process.exit(1);
  } finally {
    await db.destroy();
  }
}

run();
